export class EventLog {
    constructor(axios, deviceId) {
        this.axios = axios
        this.deviceId = deviceId
        this.logTypes = []
        this.enabled = false
    }

    getLogTypes() {
        return new Promise(async(resolve, reject) => {
            try {
                let res = await this.axios.get('/event-log-types?all=1')
                this.logTypes = res.data.data.data
                this.enabled = true
                resolve()
            } catch (e) {
                reject(e)
            }
        })
    }

    log(type, message, identifier, data) {
        if (!this.enabled) {
            return Promise.reject(new Error('logging is not enabled. Set `logging: true` in the options.'))
        }
        if (!this.logTypes.some(lt => lt.key === type)) {
            return Promise.reject(new Error(`unknown log type '${type}'`))
        }
        return new Promise((resolve, reject) => {
            this.axios.post('/event-log', {
                device_id: this.deviceId,
                type,
                message,
                identifier,
                data
            })
                .then(data => resolve(data))
                .catch(error => {
                    if (error.response) {
                        reject(new Error(error.response.data.error))
                    } else if (error.request) {
                        // The request was made but no response was received
                        reject(new Error(`${error.stack}: no response received`))
                    } else {
                        // Something happened in setting up the request that triggered an Error
                        reject(new Error(`Error! ${error.message}`))
                    }
                })
        })
    }
}
